# -*- coding: utf-8 -*-
from django.core.paginator import Paginator
from django.utils.translation import ugettext as _
from django.core.mail import EmailMultiAlternatives
from django.template.loader import get_template

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.invitation.models import FriendInvitation
from jmb.invitation.cms.models import FriendInvitationSettings

from jmb.invitation.cms.forms import FriendInvitationForm

class FriendInvitationPlugin(CMSPluginBase):
    model = FriendInvitationSettings
    name = _("Invitation Form")
    module = _("Invitation")

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = instance.form_template_name
        if request.method == "POST":
            form = FriendInvitationForm(request.POST)
            if form.is_valid():
                invitation = form.save()
                context.update({
                    'instance': instance,
                    'object': invitation
                })
                self.send_email(context, instance, form)
                self.render_template = instance.thanks_template_name
                return context
        else:
            form = FriendInvitationForm()

        context.update({
            'instance': instance,
            'form': form,
            })
        return context

    def send_email(self, context,  instance,form):
#        import ipdb; ipdb.set_trace()
        html_email = get_template(instance.email_template_name)
        html_content = html_email.render(context)
        msg = EmailMultiAlternatives(
            'hello', form.cleaned_data['message'],
            'vparenti@thunddersystems.it', (form.cleaned_data['friend_email'],)
        )
        msg.attach_alternative(html_content, "text/html")
        msg.send()

plugin_pool.register_plugin(FriendInvitationPlugin)