# -*- coding: utf-8 -*-
from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
from django.utils.http import int_to_base36

from jmb.core.utils.token import TokenGenerator
from jmb.core.db.fields import HTMLFieldTinyMCE
from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, DefaultModel

class FriendInvitation(DateModel, UserModel, StatusModel, OrderedModel):
    host = models.ForeignKey(
        User,
        db_index = True,
        blank=True, null=True,
        related_name = 'guests',
        verbose_name = _('Host'),
    )
    host_email = models.EmailField(
        verbose_name = _('Host Email'),
    )
    friend_name = models.CharField(
        max_length = 100,
        verbose_name = _('Name'),
    )
    friend_email = models.EmailField(
        verbose_name = _('Friend Email'),
    )
    message = HTMLFieldTinyMCE(
        blank=True, null=True,
        verbose_name = _('Message'),
    )
    link = models.URLField(
        verbose_name=_('URL')
    )
    visited = models.BooleanField(
        verbose_name = _('Visited')
    )

    class Meta:
        verbose_name = _("Invitation")
        verbose_name_plural = _("Invitations")
        ordering = ("-date_create",)

    def __unicode__(self):
        return u"%s" % self.friend_name

    def get_code_for_token(self):
        """
        Returns code used for token
        """
        return u"%s%s" % (
            self.id, self.link
        )
    code_for_token = property(get_code_for_token)

    def get_token(self):
        """
        Returns token string of Object
        """
        token_generator = TokenGenerator()
        return token_generator.make_token(self.code_for_token)
    token = property(get_token)

    def check_token(self, token, duration=None):
        token_generator = TokenGenerator()
        return token_generator.check_token(self.code_for_token, token, duration)

    def get_uidb36(self):
        return int_to_base36(self.id)
    uidb36 = property(get_uidb36)

if settings.CMS_ENABLED:
    import jmb.invitation.cms.plugins
#     import model.cms.app
